@@ -66,3 +66,5 @@ def org(dataset_name="", *, fileconv: bool = False, countstart=0):
                 logger.info("File already exists.")
                 break
 
+if __name__ == '__main__':
+    org()
